pub struct VippsAuthRequest {
pub redirect_url: Option<Url>,
pub request_ssn: Option<bool>,
pub request_phone: Option<bool>,
pub request_email: Option<bool>,
pub request_address: Option<bool>,
pub ref_id: Option<String>,
pub app_callback_uri: Option<Url>,
}Expand description
Request body for starting a Vipps MobilePay authentication session.
Fields
redirect_url: Option<Url>URL to redirect the user to after completing the flow.
request_ssn: Option<bool>Request the user’s Norwegian personal number.
request_phone: Option<bool>Request the user’s phone number.
request_email: Option<bool>Request the user’s email address.
request_address: Option<bool>Request the user’s registered address.
ref_id: Option<String>Reference ID returned verbatim in the result and callback.
app_callback_uri: Option<Url>(BETA) Deep-link URI to return the user to your app after authentication.
Implementations
Sourceimpl VippsAuthRequest
impl VippsAuthRequest
pub fn new() -> Self
pub fn redirect_url(self, url: Url) -> Self
pub fn request_ssn(self, v: bool) -> Self
pub fn request_phone(self, v: bool) -> Self
pub fn request_email(self, v: bool) -> Self
pub fn request_address(self, v: bool) -> Self
pub fn ref_id(self, ref_id: impl Into<String>) -> Self
pub fn app_callback_uri(self, uri: Url) -> Self